@@ -24,10 +24,10 @@ from PySide2.QtCore import QCoreApplication, QEvent, QObject, QSettings, Signal,
 import networkx as nx
 
 from spine_engine import SpineEngineState
-from spine_engine.project_item.connection import Connection
 from spine_engine.exception import EngineInitFailed
 from spine_engine.load_project_items import load_item_specification_factories
 from spine_engine.utils.serialization import deserialize_path
+from .project_item.logging_connection import HeadlessConnection
 from .config import LATEST_PROJECT_VERSION
 from .helpers import (
     make_settings_dict_for_engine,
@@ -38,6 +38,7 @@ from .helpers import (
     load_local_project_data,
     merge_dicts,
     HTMLTagFilter,
+    load_specification_local_data,
 )
 from .spine_engine_manager import make_engine_manager
 
@@ -117,7 +118,7 @@ class ModifiableProject:
         """
         self._project_dir = project_dir
         self._items = deepcopy(items_dict)
-        self._connections = [Connection.from_dict(d) for d in connection_dicts]
+        self._connections = [HeadlessConnection.from_dict(d) for d in connection_dicts]
 
     @property
     def project_dir(self):
@@ -199,7 +200,7 @@ class ActionsWithProject(QObject):
     def _dags(self):
         graph = nx.DiGraph()
         graph.add_nodes_from(self._item_dicts)
-        connections = map(Connection.from_dict, self._connection_dicts)
+        connections = map(HeadlessConnection.from_dict, self._connection_dicts)
         graph.add_edges_from(((x.source, x.destination) for x in connections))
         return [graph.subgraph(nodes) for nodes in nx.weakly_connected_components(graph)]
 
@@ -241,25 +242,29 @@ class ActionsWithProject(QObject):
         Returns:
             Status: status code
         """
-        self._app_settings = QSettings("SpineProject", "Spine Toolbox")
+        self._app_settings = QSettings("SpineProject", "Spine Toolbox", self)
         spec_factories = load_item_specification_factories("spine_items")
         self._plugin_specifications = dict()
+        self._project_dir = pathlib.Path(self._args.project).resolve()
+        config_dir = self._project_dir / ".spinetoolbox"
+        specification_local_data = load_specification_local_data(config_dir)
         for plugin_dir in plugins_dirs(self._app_settings):
             plugin_dict = load_plugin_dict(plugin_dir, self._logger)
             if plugin_dict is None:
                 continue
-            specs = load_plugin_specifications(plugin_dict, spec_factories, self._app_settings, self._logger)
+            specs = load_plugin_specifications(
+                plugin_dict, specification_local_data, spec_factories, self._app_settings, self._logger
+            )
             if specs is None:
                 continue
             for spec_list in specs.values():
                 for spec in spec_list:
                     self._plugin_specifications.setdefault(spec.item_type, []).append(spec)
-        self._project_dir = pathlib.Path(self._args.project).resolve()
-        project_dict = load_project_dict(str(self._project_dir / ".spinetoolbox"), self._logger)
+        project_dict = load_project_dict(str(config_dir), self._logger)
         version_status = self._check_project_version(project_dict)
         if version_status != Status.OK:
             return version_status
-        local_data_dict = load_local_project_data(self._project_dir / ".spinetoolbox", self._logger)
+        local_data_dict = load_local_project_data(config_dir, self._logger)
         merge_dicts(local_data_dict, project_dict)
         self._item_dicts, self._specification_dicts, self._connection_dicts, self._jump_dicts = open_project(
             project_dict, self._project_dir, self._logger
