@@ -15,13 +15,12 @@ Base classes to represent items from multiple databases in a tree.
 :authors: P. Vennström (VTT), M. Marin (KTH)
 :date:    17.6.2020
 """
-import bisect
-from PySide2.QtCore import Qt
-from ...helpers import rows_to_row_count_tuples
+from PySide2.QtCore import Qt, QTimer
+from ...helpers import rows_to_row_count_tuples, bisect_chunks, FetchParent
 from ...mvcmodels.minimal_tree_model import TreeItem
 
 
-class MultiDBTreeItem(TreeItem):
+class MultiDBTreeItem(FetchParent, TreeItem):
     """A tree item that may belong in multiple databases."""
 
     item_type = None
@@ -32,15 +31,24 @@ class MultiDBTreeItem(TreeItem):
         """Init class.
 
         Args:
-            db_mngr (SpineDBManager): a database manager
-            db_map_ids (dict): maps instances of DiffDatabaseMapping to the id of the item in that db
+            model (MinimalTreeModel, optional): item's model
+            db_map_ids (dict, optional): maps instances of DiffDatabaseMapping to the id of the item in that db
         """
         super().__init__(model)
         if db_map_ids is None:
             db_map_ids = {}
         self._db_map_ids = db_map_ids
         self._child_map = dict()  # Maps db_map to id to row number
-        self._fetched_once = False
+
+    def child_number(self):
+        try:
+            db_map, id_ = next(iter(self._db_map_ids.items()))
+        except StopIteration:
+            return -1
+        try:
+            return self.parent_item.find_row(db_map, id_)
+        except AttributeError:
+            return super().child_number()
 
     def set_data(self, column, value, role):
         raise NotImplementedError()
@@ -56,7 +64,7 @@ class MultiDBTreeItem(TreeItem):
 
     @property
     def display_id(self):
-        """"Returns an id for display based on the display key. This id must be the same across all db_maps.
+        """Returns an id for display based on the display key. This id must be the same across all db_maps.
         If it's not, this property becomes None and measures need to be taken (see update_children_by_id).
         """
         ids = {tuple(self.db_map_data_field(db_map, field) for field in self.visual_key) for db_map in self.db_maps}
@@ -66,12 +74,12 @@ class MultiDBTreeItem(TreeItem):
 
     @property
     def display_data(self):
-        """"Returns the name for display."""
+        """Returns the name for display."""
         return self.db_map_data_field(self.first_db_map, "name")
 
     @property
     def display_database(self):
-        """"Returns the database for display."""
+        """Returns the database for display."""
         return ",".join([db_map.codename for db_map in self.db_maps])
 
     @property
@@ -188,8 +196,7 @@ class MultiDBTreeItem(TreeItem):
         return [self.child_item_class(self.model, {db_map: id_}) for id_ in children_ids]
 
     def _merge_children(self, new_children):
-        """Merges new children into this item. Ensures that each children has a valid display id afterwards.
-        """
+        """Merges new children into this item. Ensures that each children has a valid display id afterwards."""
         if not new_children:
             return
         existing_children = {child.display_id: child for child in self.children}
@@ -204,41 +211,24 @@ class MultiDBTreeItem(TreeItem):
                 # No match
                 existing_children[new_child.display_id] = new_child
                 unmerged.append(new_child)
+        if not unmerged:
+            self._refresh_child_map()
+            return
         self._insert_children_sorted(unmerged)
 
     def _insert_children_sorted(self, new_children):
         """Inserts and sorts children."""
-        if not new_children:
-            return
         new_children = sorted(new_children, key=lambda x: x.display_id)
-        new_children_iter = iter(new_children)
-        child = next(new_children_iter)
-        display_ids = [child.display_id for child in self.children]
-        lo = bisect.bisect_left(display_ids, child.display_id)
-        chunk = [child]
-        for child in new_children_iter:
-            row = bisect.bisect_left(display_ids, child.display_id, lo=lo)
-            if row == lo:
-                chunk.append(child)
-                continue
-            self.insert_children(lo, chunk)
-            lo = row + len(chunk)
-            chunk = [child]
-        self.insert_children(lo, chunk)
+        for chunk, pos in bisect_chunks(self.children, new_children, key=self._children_sort_key):
+            self.insert_children(pos, chunk)
 
-    def has_children(self):
-        """Returns whether or not this item has or could have children."""
-        if self.can_fetch_more():
-            if not self._fetched_once:
-                self.fetch_more()
-                self._fetched_once = True
-            return True
-        return self.child_count()
+    @property
+    def _children_sort_key(self):
+        return lambda item: item.display_id
 
-    def fetch_successful(self, db_map, item):  # pylint: disable=no-self-use
-        return True
-
-    def _handle_fully_fetched(self):
+    def fetch_status_change(self):
+        """Notifies the view that the model's layout has changed.
+        This triggers a repaint so this item may be painted gray if no children."""
         self.model.layoutChanged.emit()
 
     @property
@@ -248,41 +238,23 @@ class MultiDBTreeItem(TreeItem):
     def can_fetch_more(self):
         if self.fetch_item_type is None:
             return False
-        return any(
-            self.db_mngr.can_fetch_more(db_map, self.fetch_item_type, parent=self)
-            or self._get_pending_children_ids(db_map)
-            for db_map in self.db_maps
-        )
+        return any(self.db_mngr.can_fetch_more(db_map, self) for db_map in self.db_maps)
 
     def fetch_more(self):
         """Fetches children from all associated databases."""
         if self.fetch_item_type is None:
             return
         for db_map in self.db_maps:
-            self.db_mngr.fetch_more(db_map, self.fetch_item_type, parent=self)
-        # Create and append children from SpineDBManager cache, in case the db items were fetched elsewhere.
-        # This is needed for object items that are created *after* the relationship classes are fetched.
-        db_map_ids = {db_map: self._get_pending_children_ids(db_map) for db_map in self.db_maps}
-        self.append_children_by_id(db_map_ids)
-
-    def _get_pending_children_ids(self, db_map):
-        """Returns a list of children ids that are in the cache but not added."""
-        if self.fetch_item_type is None:
-            return []
-        return [
-            x["id"]
-            for x in self.db_mngr.get_items(db_map, self.fetch_item_type)
-            if x["id"] not in self._child_map.get(db_map, {}) and self.fetch_successful(db_map, x)
-        ]
+            self.db_mngr.fetch_more(db_map, self)
 
     def fetch_more_if_possible(self):
         if self.can_fetch_more():
             self.fetch_more()
 
-    def get_children_ids(self, db_map):
-        if self.fetch_item_type is None:
-            return []
-        return list(self._child_map.get(db_map, {}))
+    def get_children_ids(self):
+        for db_map, ids in self._child_map.items():
+            for id_ in ids:
+                yield (db_map, id_)
 
     def append_children_by_id(self, db_map_ids):
         """
@@ -309,8 +281,7 @@ class MultiDBTreeItem(TreeItem):
         self._deep_refresh_children()
 
     def is_valid(self):  # pylint: disable=no-self-use
-        """Checks if the item is still valid after an update operation.
-        """
+        """Checks if the item is still valid after an update operation."""
         return True
 
     def update_children_by_id(self, db_map_ids):
@@ -333,8 +304,8 @@ class MultiDBTreeItem(TreeItem):
         db_map_ids_to_add = dict()
         for db_map, ids in db_map_ids.items():
             for id_ in ids:
-                row = self._child_map.get(db_map, {}).get(id_, None)
-                if row is not None:
+                row = self.find_row(db_map, id_)
+                if row != -1:
                     rows_to_update.add(row)
                 else:
                     db_map_ids_to_add.setdefault(db_map, set()).add(id_)
@@ -342,7 +313,7 @@ class MultiDBTreeItem(TreeItem):
         for db_map, ids in db_map_ids_to_add.items():
             new_children += self._create_new_children(db_map, ids)
         # Check display ids
-        display_ids = [child.display_id for child in self.children if child.display_id]
+        display_ids = [child.display_id for child in self.children if child.display_id is not None]
         for row in sorted(rows_to_update, reverse=True):
             child = self.child(row)
             if not child:
@@ -363,6 +334,9 @@ class MultiDBTreeItem(TreeItem):
                 display_ids.pop(row)
         self._deep_refresh_children()
         self._merge_children(new_children)
+        top_left = self.model.index(0, 0, self.index())
+        bottom_right = self.model.index(self.child_count() - 1, 0, self.index())
+        self.model.dataChanged.emit(top_left, bottom_right, [Qt.DisplayRole])
 
     def insert_children(self, position, children):
         """Insert new children at given position. Returns a boolean depending on how it went.
@@ -399,11 +373,14 @@ class MultiDBTreeItem(TreeItem):
                 id_ = child.db_map_id(db_map)
                 self._child_map.setdefault(db_map, dict())[id_] = row
 
+    def find_row(self, db_map, id_):
+        return self._child_map.get(db_map, {}).get(id_, -1)
+
     def find_children_by_id(self, db_map, *ids, reverse=True):
         """Generates children with the given ids in the given db_map.
         If the first id is None, then generates *all* children with the given db_map."""
         for row in self.find_rows_by_id(db_map, *ids, reverse=reverse):
-            yield self._children[row]
+            yield self.children[row]
 
     def find_rows_by_id(self, db_map, *ids, reverse=True):
         yield from sorted(self._find_unsorted_rows_by_id(db_map, *ids), reverse=reverse)
@@ -418,8 +395,8 @@ class MultiDBTreeItem(TreeItem):
         else:
             # Yield all children with the db_map *and* the id
             for id_ in ids:
-                row = self._child_map.get(db_map, {}).get(id_, None)
-                if row is not None:
+                row = self.find_row(db_map, id_)
+                if row != -1:
                     yield row
 
     def data(self, column, role=Qt.DisplayRole):
