@@ -192,7 +192,7 @@ class AddObjectClassesDialog(ShowIconColorEditorMixin, AddItemsDialog):
         self.connect_signals()
         self.model.set_horizontal_header_labels(['object_class name', 'description', 'display icon', 'databases'])
         databases = ",".join(list(self.keyed_db_maps.keys()))
-        self.default_display_icon = default_icon_id()
+        self.default_display_icon = None
         self.model.set_default_row(**{'databases': databases, 'display icon': self.default_display_icon})
         self.model.clear()
 
@@ -302,7 +302,7 @@ class AddObjectsDialog(GetObjectClassesMixin, AddItemsDialog):
         super().accept()
 
 
-class AddRelationshipClassesDialog(GetObjectClassesMixin, AddItemsDialog):
+class AddRelationshipClassesDialog(ShowIconColorEditorMixin, GetObjectClassesMixin, AddItemsDialog):
     """A dialog to query user's preferences for new relationship classes."""
 
     def __init__(self, parent, parent_item, db_mngr, *db_maps, force_default=False):
@@ -335,18 +335,29 @@ class AddRelationshipClassesDialog(GetObjectClassesMixin, AddItemsDialog):
         self.number_of_dimensions = 1
         self.connect_signals()
         self.model.set_horizontal_header_labels(
-            ['object_class name (1)', 'relationship_class name', 'description', 'databases']
+            ['object_class name (1)', 'relationship_class name', 'description', 'display icon', 'databases']
         )
         self.db_map_obj_cls_lookup = self.make_db_map_obj_cls_lookup()
         object_class_one_name = parent_item.display_data if parent_item.item_type != "root" else None
         db_names = ",".join(x.codename for x in parent_item.db_maps)
-        self.model.set_default_row(**{'object_class name (1)': object_class_one_name, 'databases': db_names})
+        self.default_display_icon = None
+        self.model.set_default_row(
+            **{
+                'object_class name (1)': object_class_one_name,
+                'display_icon': self.default_display_icon,
+                'databases': db_names,
+            }
+        )
         self.model.clear()
 
     def connect_signals(self):
         """Connect signals to slots."""
         super().connect_signals()
         self.spin_box.valueChanged.connect(self._handle_spin_box_value_changed)
+        # pylint: disable=unnecessary-lambda
+        self.table_view.itemDelegate().icon_color_editor_requested.connect(
+            lambda index: self.show_icon_color_editor(index)
+        )
 
     @Slot(int)
     def _handle_spin_box_value_changed(self, i):
@@ -399,6 +410,7 @@ class AddRelationshipClassesDialog(GetObjectClassesMixin, AddItemsDialog):
         db_map_data = dict()
         name_column = self.model.horizontal_header_labels().index("relationship_class name")
         description_column = self.model.horizontal_header_labels().index("description")
+        display_icon_column = self.model.horizontal_header_labels().index("display icon")
         db_column = self.model.horizontal_header_labels().index("databases")
         for i in range(self.model.rowCount() - 1):  # last row will always be empty
             row_data = self.model.row_data(i)
@@ -407,7 +419,10 @@ class AddRelationshipClassesDialog(GetObjectClassesMixin, AddItemsDialog):
                 self.parent().msg_error.emit("Relationship class missing at row {}".format(i + 1))
                 return
             description = row_data[description_column]
-            pre_item = {'name': relationship_class_name, 'description': description}
+            display_icon = row_data[display_icon_column]
+            if not display_icon:
+                display_icon = self.default_display_icon
+            pre_item = {'name': relationship_class_name, 'description': description, 'display_icon': display_icon}
             db_names = row_data[db_column]
             if db_names is None:
                 db_names = ""
@@ -526,8 +541,7 @@ class AddRelationshipsDialog(AddOrManageRelationshipsDialog):
 
     @Slot(int)
     def reset_model(self, index):
-        """Setup model according to current relationship_class selected in combobox.
-        """
+        """Setup model according to current relationship_class selected in combobox."""
         self.class_name, self.object_class_name_list = self.relationship_class_keys[index]
         object_class_name_list = self.object_class_name_list.split(",")
         header = object_class_name_list + ['relationship name', 'databases']
@@ -616,10 +630,8 @@ class AddRelationshipsDialog(AddOrManageRelationshipsDialog):
         super().accept()
 
 
-# FIXME: Make models lazy
 class ManageRelationshipsDialog(AddOrManageRelationshipsDialog):
-    """A dialog to query user's preferences for managing relationships.
-    """
+    """A dialog to query user's preferences for managing relationships."""
 
     def __init__(self, parent, parent_item, db_mngr, *db_maps):
         """
@@ -714,8 +726,7 @@ class ManageRelationshipsDialog(AddOrManageRelationshipsDialog):
 
     @Slot(int)
     def reset_model(self, index):
-        """Setup model according to current relationship_class selected in combobox.
-        """
+        """Setup model according to current relationship_class selected in combobox."""
         self.class_name, self.object_class_name_list = self.relationship_class_keys[index]
         object_class_name_list = self.object_class_name_list.split(",")
         self.model.set_horizontal_header_labels(object_class_name_list)
@@ -727,10 +738,12 @@ class ManageRelationshipsDialog(AddOrManageRelationshipsDialog):
             rel_cls = relationship_classes.get((self.class_name, self.object_class_name_list), None)
             if rel_cls is None:
                 continue
-            for relationship in self.db_mngr.get_items_by_field(db_map, "relationship", "class_id", rel_cls["id"]):
+            for relationship in self.db_mngr.get_items_by_field(
+                db_map, "relationship", "class_id", rel_cls["id"], only_visible=False
+            ):
                 key = tuple(relationship["object_name_list"].split(","))
                 self.relationship_ids[key] = relationship["id"]
-        existing_items = list(self.relationship_ids)
+        existing_items = sorted(self.relationship_ids)
         self.existing_items_model.reset_model(existing_items)
         self.model.refresh()
         self.model.modelReset.emit()
@@ -744,7 +757,7 @@ class ManageRelationshipsDialog(AddOrManageRelationshipsDialog):
             header_item = QTreeWidgetItem([name])
             header_item.setTextAlignment(0, Qt.AlignHCenter)
             tree_widget.setHeaderItem(header_item)
-            objects = self.db_mngr.get_items_by_field(self.db_map, "object", "class_name", name)
+            objects = self.db_mngr.get_items_by_field(self.db_map, "object", "class_name", name, only_visible=False)
             items = [QTreeWidgetItem([obj["name"]]) for obj in objects]
             tree_widget.addTopLevelItems(items)
             tree_widget.resizeColumnToContents(0)
@@ -781,7 +794,6 @@ class ManageRelationshipsDialog(AddOrManageRelationshipsDialog):
         super().accept()
 
 
-# FIXME: make models here lazy
 class ObjectGroupDialogBase(QDialog):
     def __init__(self, parent, object_class_item, db_mngr, *db_maps):
         """
@@ -848,7 +860,7 @@ class ObjectGroupDialogBase(QDialog):
             db_map: {
                 x["name"]: x["id"]
                 for x in self.db_mngr.get_items_by_field(
-                    self.db_map, "object", "class_id", self.object_class_item.db_map_id(db_map)
+                    self.db_map, "object", "class_id", self.object_class_item.db_map_id(db_map), only_visible=False
                 )
             }
             for db_map in db_maps
@@ -867,7 +879,8 @@ class ObjectGroupDialogBase(QDialog):
         object_ids = self.db_map_object_ids[self.db_map]
         members = []
         non_members = []
-        for obj_name, obj_id in object_ids.items():
+        for obj_name in sorted(object_ids):
+            obj_id = object_ids[obj_name]
             if obj_id in self.initial_member_ids():
                 members.append(obj_name)
             elif obj_id != self.initial_entity_id():
@@ -978,8 +991,13 @@ class ManageMembersDialog(ObjectGroupDialogBase):
         self.reset_list_widgets(db_maps[0].codename)
         self.connect_signals()
 
+    def _entity_groups(self):
+        return self.db_mngr.get_items_by_field(
+            self.db_map, "entity_group", "group_id", self.initial_entity_id(), only_visible=False
+        )
+
     def initial_member_ids(self):
-        return set(self.object_item.db_map_member_ids(self.db_map))
+        return {x["member_id"] for x in self._entity_groups()}
 
     def initial_entity_id(self):
         return self.object_item.db_map_id(self.db_map)
@@ -998,9 +1016,7 @@ class ManageMembersDialog(ObjectGroupDialogBase):
         items_to_add = [
             {"entity_id": obj["id"], "entity_class_id": obj["class_id"], "member_id": member_id} for member_id in added
         ]
-        ids_to_remove = [
-            x["id"] for x in self.object_item.db_map_entity_groups(self.db_map) if x["member_id"] in removed
-        ]
+        ids_to_remove = [x["id"] for x in self._entity_groups() if x["member_id"] in removed]
         if not items_to_add and not ids_to_remove:
             super().accept()
             return
