@@ -21,7 +21,7 @@ from PySide2.QtWidgets import QDialog, QDialogButtonBox, QHeaderView, QGridLayou
 from PySide2.QtCore import Slot, Qt, QModelIndex
 from ...widgets.custom_editors import IconColorEditor
 from ...widgets.custom_qtableview import CopyPasteTableView
-from ...helpers import busy_effect
+from ...helpers import busy_effect, preferred_row_height
 
 
 class ManageItemsDialogBase(QDialog):
@@ -38,7 +38,7 @@ class ManageItemsDialogBase(QDialog):
         self.table_view.horizontalHeader().setSectionResizeMode(QHeaderView.Interactive)
         self.table_view.horizontalHeader().setStretchLastSection(True)
         self.table_view.horizontalHeader().setMinimumSectionSize(120)
-        self.table_view.verticalHeader().setDefaultSectionSize(parent.default_row_height)
+        self.table_view.verticalHeader().setDefaultSectionSize(preferred_row_height(self))
         self._accept_action = QAction("OK", parent=self)
         self._accept_action.setShortcut("Ctrl+Return")
         self.addAction(self._accept_action)
@@ -117,15 +117,13 @@ class ManageItemsDialog(ManageItemsDialogBase):
         self.resize_window_to_columns()
 
 
-# FIXME: We need to fully fetch the corresponding table before calling db_mngr.get_items
-
-
 class GetObjectClassesMixin:
     """Provides a method to retrieve object classes for AddObjectsDialog and AddRelationshipClassesDialog."""
 
     def make_db_map_obj_cls_lookup(self):
         return {
-            db_map: {x["name"]: x for x in self.db_mngr.get_items(db_map, "object_class")} for db_map in self.db_maps
+            db_map: {x["name"]: x for x in self.db_mngr.get_items(db_map, "object_class", only_visible=False)}
+            for db_map in self.db_maps
         }
 
     def object_class_name_list(self, row):
@@ -151,7 +149,9 @@ class GetObjectsMixin:
 
     def make_db_map_obj_lookup(self):
         return {
-            db_map: {(x["class_id"], x["name"]): x for x in self.db_mngr.get_items(db_map, "object")}
+            db_map: {
+                (x["class_id"], x["name"]): x for x in self.db_mngr.get_items(db_map, "object", only_visible=False)
+            }
             for db_map in self.db_maps
         }
 
@@ -186,7 +186,7 @@ class GetRelationshipClassesMixin:
         return {
             db_map: {
                 (x["name"], x["object_class_name_list"]): x
-                for x in self.db_mngr.get_items(db_map, "relationship_class")
+                for x in self.db_mngr.get_items(db_map, "relationship_class", only_visible=False)
             }
             for db_map in self.db_maps
         }
