@@ -65,75 +65,73 @@ def do_create_new_spine_database(url):
 class SpineDBManager(QObject):
     """Class to manage DBs within a project."""
 
-    error_msg = Signal(object)
+    error_msg = Signal(dict)
     session_refreshed = Signal(set)
     session_committed = Signal(set, object)
     session_rolled_back = Signal(set)
     # Added
-    scenarios_added = Signal(object)
-    alternatives_added = Signal(object)
-    object_classes_added = Signal(object)
-    objects_added = Signal(object)
-    relationship_classes_added = Signal(object)
-    relationships_added = Signal(object)
-    entity_groups_added = Signal(object)
-    parameter_definitions_added = Signal(object)
-    parameter_values_added = Signal(object)
-    parameter_value_lists_added = Signal(object)
-    list_values_added = Signal(object)
-    features_added = Signal(object)
-    tools_added = Signal(object)
-    tool_features_added = Signal(object)
-    tool_feature_methods_added = Signal(object)
-    metadata_added = Signal(object)
-    entity_metadata_added = Signal(object)
-    parameter_value_metadata_added = Signal(object)
+    scenarios_added = Signal(dict)
+    alternatives_added = Signal(dict)
+    object_classes_added = Signal(dict)
+    objects_added = Signal(dict)
+    relationship_classes_added = Signal(dict)
+    relationships_added = Signal(dict)
+    entity_groups_added = Signal(dict)
+    parameter_definitions_added = Signal(dict)
+    parameter_values_added = Signal(dict)
+    parameter_value_lists_added = Signal(dict)
+    list_values_added = Signal(dict)
+    features_added = Signal(dict)
+    tools_added = Signal(dict)
+    tool_features_added = Signal(dict)
+    tool_feature_methods_added = Signal(dict)
+    metadata_added = Signal(dict)
+    entity_metadata_added = Signal(dict)
+    parameter_value_metadata_added = Signal(dict)
     # Removed
-    scenarios_removed = Signal(object)
-    alternatives_removed = Signal(object)
-    object_classes_removed = Signal(object)
-    objects_removed = Signal(object)
-    relationship_classes_removed = Signal(object)
-    relationships_removed = Signal(object)
-    entity_groups_removed = Signal(object)
-    parameter_definitions_removed = Signal(object)
-    parameter_values_removed = Signal(object)
-    parameter_value_lists_removed = Signal(object)
-    list_values_removed = Signal(object)
-    features_removed = Signal(object)
-    tools_removed = Signal(object)
-    tool_features_removed = Signal(object)
-    tool_feature_methods_removed = Signal(object)
-    metadata_removed = Signal(object)
-    entity_metadata_removed = Signal(object)
-    parameter_value_metadata_removed = Signal(object)
-    items_removed = Signal(object)
+    scenarios_removed = Signal(dict)
+    alternatives_removed = Signal(dict)
+    object_classes_removed = Signal(dict)
+    objects_removed = Signal(dict)
+    relationship_classes_removed = Signal(dict)
+    relationships_removed = Signal(dict)
+    entity_groups_removed = Signal(dict)
+    parameter_definitions_removed = Signal(dict)
+    parameter_values_removed = Signal(dict)
+    parameter_value_lists_removed = Signal(dict)
+    list_values_removed = Signal(dict)
+    features_removed = Signal(dict)
+    tools_removed = Signal(dict)
+    tool_features_removed = Signal(dict)
+    tool_feature_methods_removed = Signal(dict)
+    metadata_removed = Signal(dict)
+    entity_metadata_removed = Signal(dict)
+    parameter_value_metadata_removed = Signal(dict)
+    items_removed = Signal(dict)
     # Updated
-    scenarios_updated = Signal(object)
-    alternatives_updated = Signal(object)
-    object_classes_updated = Signal(object)
-    objects_updated = Signal(object)
-    relationship_classes_updated = Signal(object)
-    relationships_updated = Signal(object)
-    parameter_definitions_updated = Signal(object)
-    parameter_values_updated = Signal(object)
-    parameter_value_lists_updated = Signal(object)
-    list_values_updated = Signal(object)
-    features_updated = Signal(object)
-    tools_updated = Signal(object)
-    tool_features_updated = Signal(object)
-    tool_feature_methods_updated = Signal(object)
-    metadata_updated = Signal(object)
-    entity_metadata_updated = Signal(object)
-    parameter_value_metadata_updated = Signal(object)
+    scenarios_updated = Signal(dict)
+    alternatives_updated = Signal(dict)
+    object_classes_updated = Signal(dict)
+    objects_updated = Signal(dict)
+    relationship_classes_updated = Signal(dict)
+    relationships_updated = Signal(dict)
+    parameter_definitions_updated = Signal(dict)
+    parameter_values_updated = Signal(dict)
+    parameter_value_lists_updated = Signal(dict)
+    list_values_updated = Signal(dict)
+    features_updated = Signal(dict)
+    tools_updated = Signal(dict)
+    tool_features_updated = Signal(dict)
+    tool_feature_methods_updated = Signal(dict)
+    metadata_updated = Signal(dict)
+    entity_metadata_updated = Signal(dict)
+    parameter_value_metadata_updated = Signal(dict)
     # Uncached
-    items_removed_from_cache = Signal(object)
+    items_removed_from_cache = Signal(dict)
     # Internal
-    scenario_alternatives_added = Signal(object)
-    scenario_alternatives_updated = Signal(object)
-    scenario_alternatives_removed = Signal(object)
-    # Fetched
-    db_map_fetched = Signal(object)
+    scenario_alternatives_added = Signal(dict)
+    scenario_alternatives_updated = Signal(dict)
+    scenario_alternatives_removed = Signal(dict)
     # Closing
     waiting_for_fetcher = Signal()
     fetcher_waiting_over = Signal()
